Bifrost: src/CompactedDBG.hpp File Reference

Bifrost

Data Structures | Typedefs
CompactedDBG.hpp File Reference

Interface for the Compacted de Bruijn graph API. More...

Go to the source code of this file.

## Data Structures
struct | CDBG_Build_opt
| Most members of this structure are parameters for CompactedDBG<U, G>::build(), except for: More...
class | CDBG_Data_t< Unitig_data_t, Graph_data_t >
| If data are to be associated with the unitigs of the compacted de Bruijn graph, those data must be wrapped into a class that inherits from the abstract class CDBG_Data_t. More...
class | CompactedDBG< Unitig_data_t, Graph_data_t >
| Represent a Compacted de Bruijn graph. More...

## Typedefs
template<typename U , typename G >
using | const_UnitigMap = UnitigMap< U, G, true >
| const_UnitigMap is a constant UnitigMap. More...

## Detailed Description

Interface for the Compacted de Bruijn graph API.

Code snippets using this interface are provided in snippets/test.cpp.

## Typedef Documentation

## ◆ const_UnitigMap

template<typename U , typename G >

const_UnitigMap

const_UnitigMap is a constant UnitigMap.

The main difference in its usage with a UnitigMap object is when you call the method UnitigMap::getGraph(): with a const_UnitigMap, this method returns a pointer to a constant CompactedDBG (you can't modify it).